# Karvi
A small package with some custom templates and scripts for Django projects.

## Requirements
 - [Python](https://www.python.org) 3.6
 - [Django](https://www.djangoproject.com) 2.0

## Projects in use
 - [Bulma](https://bulma.io) 0.7
 - [TypeScript](https://www.typescriptlang.org) 3.2
 - [Laravel Mix](https://github.com/JeffreyWay/laravel-mix) 4.0
 - [Yarn](https://yarnpkg.com)
 - [Pipenv](https://github.com/pypa/pipenv)
